import request from '@/utils/request'

//获取专业/班级列表
export function systemUserMajorList(data) {
  return request({
    url: '/system/user/major/list',
    method: 'post',
    data: data
  })
}

//新增专业/班级
export function systemUserMajorAdd(data) {
  return request({
    url: '/system/user/major/add',
    method: 'post',
    data: data
  })
}

//专业/班级详情
export function systemUserMajorDetail(query) {
  return request({
    url: '/system/user/major/detail',
    method: 'get',
    params: query
  })
}

//编辑专业/班级
export function systemUserMajorUpdate(data) {
  return request({
    url: '/system/user/major/update',
    method: 'post',
    data: data
  })
}

//删除专业/班级
export function systemUserMajorDelete(data) {
  return request({
    url: '/system/user/major/delete',
    method: 'post',
    data: data
  })
}

//批量绑卡
export function systemUserBatchBindCard(data) {
  return request({
    url: '/system/user/batchBindCard',
    method: 'post',
    data: data
  })
}

//新增 校区/楼栋/楼层
export function systemBuildingGetTreeAdd(data) {
  return request({
    url: '/system/building/add',
    method: 'post',
    data: data
  })
}

//编辑 校区/楼栋/楼层
export function systemBuildingGetUpdate(data) {
  return request({
    url: '/system/building/update',
    method: 'post',
    data: data
  })
}

//获取楼栋楼层列表
export function systemBuildingGetList(data) {
  return request({
    url: '/system/building/getlist',
    method: 'post',
    data: data
  })
}

//楼栋楼层排序
export function systemBuildingEditSortNum(data) {
  return request({
    url: '/system/building/editSortNum',
    method: 'post',
    data: data
  })
}

//楼栋楼层删除
export function systemBuildingEditDelete(data) {
  return request({
    url: '/system/building/delete',
    method: 'post',
    data: data
  })
}

//获取楼层下房间列表
export function systemRoomInfoList(data) {
  return request({
    url: '/system/roomInfo/list',
    method: 'post',
    data: data
  })
}
//新增房间
export function systemRoomInfoAdd(data) {
  return request({
    url: '/system/roomInfo/add',
    method: 'post',
    data: data
  })
}
//修改房间
export function systemRoomInfoUpdate(data) {
  return request({
    url: '/system/roomInfo/update',
    method: 'post',
    data: data
  })
}
//删除房间
export function systemRoomInfoDelete(data) {
  return request({
    url: '/system/roomInfo/delete',
    method: 'post',
    data: data
  })
}
//房间详情
export function systemRoomInfoDetail(query) {
  return request({
    url: '/system/roomInfo/detail',
    method: 'get',
    params: query
  })
}
/****************安全分类****************/
//分类认定条件
export function laboratoryClassTypeGetClassCriteria(query) {
  return request({
    url: '/laboratory/classType/getClassCriteria',
    method: 'get',
    params: query
  })
}
//分级认定条件
export function laboratoryClassTypeGetClassCriteriaLevel(query) {
  return request({
    url: '/laboratory/classType/getClassCriteriaLevel',
    method: 'get',
    params: query
  })
}
//安全分类列表
export function laboratoryClassTypeList(data) {
  return request({
    url: '/laboratory/classType/list',
    method: 'post',
    data: data
  })
}

//安全分类新增
export function laboratoryClassTypeAdd(data) {
  return request({
    url: '/laboratory/classType/add',
    method: 'post',
    data: data
  })
}

//安全分类编辑
export function laboratoryClassTypeUpdate(data) {
  return request({
    url: '/laboratory/classType/update',
    method: 'post',
    data: data
  })
}

//安全分类详情
export function laboratoryClassTypeDetail(query) {
  return request({
    url: '/laboratory/classType/detail',
    method: 'get',
    params: query
  })
}

//安全分类删除
export function laboratoryClassTypeDelete(data) {
  return request({
    url: '/laboratory/classType/delete',
    method: 'post',
    data: data
  })
}

/****************安全分级****************/
//安全分级列表
export function laboratoryClassLevelList(data) {
  return request({
    url: '/laboratory/classLevel/list',
    method: 'post',
    data: data
  })
}

//安全分级新增
export function laboratoryClassLevelAdd(data) {
  return request({
    url: '/laboratory/classLevel/add',
    method: 'post',
    data: data
  })
}

//安全分级编辑
export function laboratoryClassLevelUpdate(data) {
  return request({
    url: '/laboratory/classLevel/update',
    method: 'post',
    data: data
  })
}

//安全分级详情
export function laboratoryClassLevelDetail(query) {
  return request({
    url: '/laboratory/classLevel/detail',
    method: 'get',
    params: query
  })
}

//安全分级删除
export function laboratoryClassLevelDelete(data) {
  return request({
    url: '/laboratory/classLevel/delete',
    method: 'post',
    data: data
  })
}
/****************实验室类型****************/
//实验室类型列表
export function laboratoryClassMoldList(data) {
  return request({
    url: '/laboratory/classMold/list',
    method: 'post',
    data: data
  })
}

//实验室类型新增
export function laboratoryClassMoldAdd(data) {
  return request({
    url: '/laboratory/classMold/add',
    method: 'post',
    data: data
  })
}

//实验室类型编辑
export function laboratoryClassMoldUpdate(data) {
  return request({
    url: '/laboratory/classMold/update',
    method: 'post',
    data: data
  })
}

//实验室类型详情
export function laboratoryClassMoldDetail(query) {
  return request({
    url: '/laboratory/classMold/detail',
    method: 'get',
    params: query
  })
}

//实验室类型删除
export function laboratoryClassMoldDelete(data) {
  return request({
    url: '/laboratory/classMold/delete',
    method: 'post',
    data: data
  })
}

/***********************实验室**************************/

//实验室列表
export function laboratorySubRelInfoList(data) {
  return request({
    url: '/laboratory/subRelInfo/list',
    method: 'post',
    data: data
  })
}

//实验室-新增
export function laboratorySubRelInfoAdd(data) {
  return request({
    url: '/laboratory/subRelInfo/add',
    method: 'post',
    data: data
  })
}
//实验室-编辑
export function laboratorySubRelInfoUpdate(data) {
  return request({
    url: '/laboratory/subRelInfo/update',
    method: 'post',
    data: data
  })
}
//实验室-关联配置-详情
export function laboratorySubRelInfoGetHazardSubRelInfo(query) {
  return request({
    url: '/laboratory/subRelInfo/getHazardSubRelInfo',
    method: 'get',
    params: query
  })
}
//实验室-关联配置-提交
export function laboratorySubRelInfoUpdateHazardSubRel(data) {
  return request({
    url: '/laboratory/subRelInfo/updateHazardSubRel',
    method: 'post',
    data: data
  })
}
//实验室-详情获取危险源/关联配置信息
export function laboratorySubRelInfoGetSubRelByCheckHazard(query) {
  return request({
    url: '/laboratory/subRelInfo/getSubRelByCheckHazard',
    method: 'get',
    params: query
  })
}
//实验室-详情
export function laboratorySubRelInfoGetDetailInfo(query) {
  return request({
    url: '/laboratory/subRelInfo/getDetailInfo',
    method: 'get',
    params: query
  })
}
//实验室-删除
export function laboratorySubRelInfoGetDetailDelete(data) {
  return request({
    url: '/laboratory/subRelInfo/delete',
    method: 'post',
    data: data
  })
}
//实验室-排序修改
export function laboratorySubRelInfoUpdateBySort(data) {
  return request({
    url: '/laboratory/subRelInfo/updateBySort',
    method: 'post',
    data: data
  })
}
//准入配置-查询实验室-获取准入模板列表
export function laboratorySubMaterialListData(query) {
  return request({
    url: '/laboratory/subMaterial/listData',
    method: 'get',
    params: query
  })
}
//准入配置-提交
export function laboratorySubMaterialAdd(data) {
  return request({
    url: '/laboratory/subMaterial/add',
    method: 'post',
    data: data
  })
}
//准入配置-人员登录授权方式下拉菜单
export function laboratoryUserAuthAuthTypeList(query) {
  return request({
    url: '/laboratory/userAuth/authTypeList',
    method: 'get',
    params: query
  })
}


/******************* 安全信息类目 *********************/
//安全信息类目-列表
export function laboratoryInfoBrandList(data) {
  return request({
    url: '/laboratory/infoBrand/list',
    method: 'post',
    data: data
  })
}
// 安全信息类目-新增
export function laboratoryInfoBrandAdd(data) {
  return request({
    url: '/laboratory/infoBrand/add',
    method: 'post',
    data: data
  })
}
// 安全信息类目-编辑
export function laboratoryInfoBrandUpdate(data) {
  return request({
    url: '/laboratory/infoBrand/update',
    method: 'post',
    data: data
  })
}
// 安全信息类目-删除
export function laboratoryInfoBrandDelete(data) {
  return request({
    url: '/laboratory/infoBrand/delete',
    method: 'post',
    data: data
  })
}
// 安全信息类目-信息配置-列表
export function laboratoryBrandDetailList(data) {
  return request({
    url: '/laboratory/brandDetail/list',
    method: 'post',
    data: data
  })
}
// 安全信息类目-信息配置-新增
export function laboratoryBrandDetailAdd(data) {
  return request({
    url: '/laboratory/brandDetail/add',
    method: 'post',
    data: data
  })
}
// 安全信息类目-信息配置-编辑
export function laboratoryBrandDetailUpdate(data) {
  return request({
    url: '/laboratory/brandDetail/update',
    method: 'post',
    data: data
  })
}
// 安全信息类目-信息配置-删除
export function laboratoryBrandDetailDelete(data) {
  return request({
    url: '/laboratory/brandDetail/delete',
    method: 'post',
    data: data
  })
}

//查询安全信息配置列表
export function laboratoryInfoBrandGetClassifyBySubId(query) {
  return request({
    url: '/laboratory/infoBrand/getClassifyBySubId',
    method: 'get',
    params: query
  })
}
/******************* 布局管理 *********************/

//根据楼层获取房间列表
export function laboratoryBuildLayoutList(data) {
  return request({
    url: '/laboratory/buildLayout/list',
    method: 'post',
    data: data
  })
}

//根据楼层获取房间列表与布局信息
export function laboratoryBuildLayoutGetTreeSonList(data) {
  return request({
    url: '/laboratory/buildLayout/getTreeSonList',
    method: 'post',
    data: data
  })
}

//获取楼层房间列表(用于布局选择房间)
export function laboratoryBuildLayoutGetList(data) {
  return request({
    url: '/laboratory/buildLayout/getList',
    method: 'post',
    data: data
  })
}

//保存布局设置
export function laboratoryExitLineAdd(data) {
  return request({
    url: '/laboratory/exitLine/add',
    method: 'post',
    data: data
  })
}

//职位(身份)-列表
export function systemPostList(data) {
  return request({
    url: '/system/post/list',
    method: 'post',
    data: data
  })
}

//职位(身份)-详情
export function systemPostDetail(query) {
  return request({
    url: '/system/post/detail',
    method: 'get',
    params: query
  })
}

//职位(身份)-新增
export function systemPostAdd(data) {
  return request({
    url: '/system/post/add',
    method: 'post',
    data: data
  })
}

//职位(身份)-修改
export function systemPostUpdate(data) {
  return request({
    url: '/system/post/update',
    method: 'post',
    data: data
  })
}
//职位(身份)-删除
export function systemPostDelete(data) {
  return request({
    url: '/system/post/delete',
    method: 'post',
    data: data
  })
}
/***************** 课题组 *****************/

//课题组-列表
export function systemTopicList(data) {
  return request({
    url: '/system/topic/list',
    method: 'post',
    data: data
  })
}

//课题组-新增
export function systemTopicAdd(data) {
  return request({
    url: '/system/topic/add',
    method: 'post',
    data: data
  })
}

//课题组-编辑
export function systemTopicEdit(data) {
  return request({
    url: '/system/topic/edit',
    method: 'post',
    data: data
  })
}

//课题组-详情
export function systemTopicDetail(query) {
  return request({
    url: '/system/topic/detail',
    method: 'get',
    params: query
  })
}

//课题组-删除
export function systemTopicTopicDel(data) {
  return request({
    url: '/system/topic/topicDel',
    method: 'post',
    data: data
  })
}

//课题组-启用/停用
export function systemTopicEditTopicStart(data) {
  return request({
    url: '/system/topic/editTopicStart',
    method: 'post',
    data: data
  })
}

//课题组-查询成员
export function systemTopicMemberList(data) {
  return request({
    url: '/system/topic/memberList',
    method: 'post',
    data: data
  })
}

//课题组成员-启用/停用
export function systemTopicEditMemberStart(data) {
  return request({
    url: '/system/topic/editMemberStart',
    method: 'post',
    data: data
  })
}

//危险源-列表
export function laboratoryHazardList(data) {
  return request({
    url: '/laboratory/hazard/list',
    method: 'post',
    data: data
  })
}
//危险源-新增
export function laboratoryHazardAdd(data) {
  return request({
    url: '/laboratory/hazard/add',
    method: 'post',
    data: data
  })
}
//危险源-编辑
export function laboratoryHazardUpdate(data) {
  return request({
    url: '/laboratory/hazard/update',
    method: 'post',
    data: data
  })
}
//危险源-删除
export function laboratoryHazardDelete(data) {
  return request({
    url: '/laboratory/hazard/delete',
    method: 'post',
    data: data
  })
}

//危险源-详情
export function laboratoryHazardDetail(query) {
  return request({
    url: '/laboratory/hazard/detail',
    method: 'get',
    params: query
  })
}

/********************** 值班/巡查 **********************/

//查询值班列表
export function laboratoryXxpDutyListYmd(query) {
  return request({
    url: '/laboratory/boardDuty/listYmd',
    method: 'get',
    params: query
  })
}
//添加值班人员
export function laboratoryXxpDutyAdd(data) {
  return request({
    url: '/laboratory/boardDuty/add',
    method: 'post',
    data: data
  })
}
//获取树状实验室列表接口
export function laboratorySubRelInfoGetDeptInSubList(data) {
  return request({
    url: '/laboratory/subRelInfo/getDeptInSubList',
    method: 'post',
    data: data
  })
}
//获取实验室可选值班人员列表
export function laboratoryWhiteGetUserDutyList(data) {
  return request({
    url: '/laboratory/white/getUserDutyList',
    method: 'post',
    data: data
  })
}
//巡查列表查询
export function laboratoryXxpInspectionListYmd(query) {
  return request({
    url: '/laboratory/boardPatrol/listYmd',
    method: 'get',
    params: query
  })
}

//值班人员详情接口
export function laboratoryXxpDutyGetInfoByDate(query) {
  return request({
    url: '/laboratory/boardDuty/getInfoByDate',
    method: 'get',
    params: query
  })
}
export function delXxpDuty(id) {
  return request({
    url: '/laboratory/boardDuty/'+id,
    method: 'post',
  })
}

//获取异常记录
export function listAbnormal(query) {
  return request({
    url: '/laboratory/boardPatrol/listAbnormal',
    method: 'get',
    params: query
  })
}

//获取正常记录
export function listStandard(query) {
  return request({
    url: 'laboratory/boardPatrol/listStandard',
    method: 'get',
    params: query
  })
}

//进出记录-列表
export function laboratorySubPassOutList(data) {
  return request({
    url: '/laboratory/subPassOut/list',
    method: 'post',
    data: data
  })
}
//进出记录-个人列表
export function laboratorySubPassOutMyList(data) {
  return request({
    url: '/laboratory/subPassOut/myList',
    method: 'post',
    data: data
  })
}
//进出记录-照片列表
export function laboratorySubPassOutPhotoList(data) {
  return request({
    url: '/laboratory/subPassOut/photoList',
    method: 'post',
    data: data
  })
}
//进出记录-有记录的实验室列表
export function laboratorySubPassOutCheckedSubList(data) {
  return request({
    url: '/laboratory/subPassOut/checkedSubList',
    method: 'post',
    data: data
  })
}
