<!--安全信息配置-->
<template>
  <div class="safetyInfoConfig">
    <div class="title-box">
      <div @click="titleClick(1)">
        <p>安全类目</p>
        <p></p>
      </div>
      <div @click="titleClick(2)">
        <p>信息配置</p>
        <p class="bottom-p-color"></p>
      </div>
    </div>
    <div class="config_main">
      <div class="config_main_l scrollbar-box">
        <div class="config_main_l_title">
          <img  src="@/assets/ZDimages/integratedManagement/icon_xxpz_aqxxlm.png">
          安全信息类目
        </div>
        <div :class='currentIndex==index?"active":""' class="config_main_l_li"
             v-for="(item,index) in tabsList" :key="index" @click="handleTabClick(item,index)">
          {{item.brandName}}
        </div>
      </div>
      <p class="config_main_border"></p>
      <div class="approval_handle-page">
        <div>
          <p class="page-submit-common-style-button"
             style="float: right;margin-bottom:20px;"
             @click="handleClick('','','add')"
             v-hasPermiRouter="['lab:infoBrand:add']"
          >新增</p>
        </div>
        <el-table class="table-box" border v-loading="loading" :data="tableData">
          <el-table-column label="排序" align="left" class-name="small-padding fixed-width" width="80">
            <template slot-scope="scope">
              <el-input
                onkeyup="value=value.replace(/[^\d]/g,'')"
                class="serial"
                v-model="scope.row.orderNum"
                @change="categorySort(scope.row)"
                maxLength="3"
                placeholder="序号">
              </el-input>
            </template>
          </el-table-column>
          <el-table-column label="信息名称" align="left" prop="infoName"/>
          <el-table-column label="公共信息" align="left">
            <template slot-scope="scope">
              <el-switch
                @click.native="categoryShow(scope.row)"
                class="switch captcha-img"
                :active-value="true"
                :inactive-value="false"
                active-color="#FF9900"
                inactive-color="#999"
                v-model="scope.row.isCollective"
                active-text="是"
                inactive-text="否"
                disabled
              ></el-switch>
            </template>
          </el-table-column>
          <el-table-column label="添加人" align="left" prop="createName"/>
          <el-table-column label="添加时间" align="left" prop="createTime">
            <template slot-scope="scope">
              <span>{{ parseTime(scope.row.createTime,"{y}-{m}-{d} {h}:{i}") }}</span>
            </template>
          </el-table-column>
          <el-table-column label="操作" align="left" class-name="small-padding fixed-width" width="120" v-if="tableButtonType">
            <template slot-scope="scope">
              <div class="table-button-box">
                <p class="table-button-null"></p>
                <p class="table-button-p"
                   v-hasPermiRouter="['lab:infoBrand:edit']"
                   @click="handleClick('',scope.row,'edit')"
                >编辑</p>
                <p class="table-button-p"
                   v-hasPermiRouter="['lab:infoBrand:del']"
                   @click="handleClick('',scope.row,'delete')"
                >删除</p>
                <p class="table-button-null"></p>
              </div>
            </template>
          </el-table-column>
        </el-table>
        <pagination :page-sizes="[20, 30, 40, 50]"
                    :total="total"
                    layout="total, prev, pager, next, sizes, jumper"
                    :page.sync="queryParams.page"
                    :limit.sync="queryParams.pageSize"
                    @pagination="getList"
        />
      </div>
    </div>


    <!-- 添加或修改安全分级对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body :before-close="closeDialog" :close-on-click-modal="false">
      <el-form ref="form" :model="form" :rules="rules" label-width="80px" >
        <el-form-item label="信息名称" prop="infoName">
          <el-input v-model="form.infoName" maxlength="100" placeholder="请输入名称" style="width:320px;"/>
        </el-form-item>
        <el-form-item label="信息类目"  prop="brandId" class="form-item">
          <el-select placeholder="请选择类目" v-model="form.brandId" style="width:320px;" @change="categoryClick()">
            <el-option
              v-for="dict in categoryList"
              :key="dict.brandId"
              :label="dict.brandName"
              :value="dict.brandId"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="信息类型">
          <el-input v-model="form.infoType==1?'文字':'图片'"   placeholder="" disabled style="width:320px;"/>
        </el-form-item>
        <el-form-item label="信息内容" prop="infoContent" v-if="form.infoType==1">
          <el-input type="textarea" v-model="form.infoContent"  maxlength="200" placeholder="请输入内容" style="width:320px;"/>
        </el-form-item>
        <el-form-item label="信息内容" prop="infoContent" v-if="form.infoType==2">
          <el-upload
            class="certificate-avatar-uploader"
            :action="uploadImgUrl"
            :show-file-list="false"
            :on-success="handleAvatarSuccess"
            :headers="headers"
            :before-upload="beforeAvatarUpload">
            <div style="display: flex;">
              <img v-if="form.infoContent" :src="form.infoContent" style="width: 80px;height: 80px;margin-right: 10px">
              <i v-if="!form.infoContent" class="el-icon-plus avatar-uploader-icon"></i>
            </div>
          </el-upload>
        </el-form-item>
        <P v-if="form.infoType==2" style="margin-left: 80px">图片最大上传630*78，建议尺寸58*78</P>
      </el-form>
      <div slot="footer" class="dialog-footer dialog-footer-box">
        <p class="dialog-footer-button-null"></p>
        <p class="dialog-footer-button-info" @click="cancel">取消</p>
        <p class="dialog-footer-button-primary" @click="submitForm">提交</p>
        <p class="dialog-footer-button-null"></p>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { getToken } from "@/utils/auth";
import { laboratoryInfoBrandList , laboratoryBrandDetailAdd, laboratoryBrandDetailList, laboratoryBrandDetailUpdate, laboratoryBrandDetailDelete } from '@/api/integratedManagement/index'
export default {
  name: "Approval",
  data() {
    return {
      tableButtonType:this.hasPermiDom(['lab:infoBrand:edit','lab:infoBrand:del',]),
      uploadImgUrl: this.uploadUrl(), // 上传的图片服务器地址
      activeName: '',
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      //页面状态
      pageType:1,
      loading:false,
      headers: {
        Authorization: getToken()
      },
      // 查询参数
      queryParams: {
        page: 1,
        pageSize:20,
        brandId:'',
      },
      total:0,
      tableData:[],
      dateRange:[],
      pageData2:{},
      tabsList:[],
      categoryList:[],
      // 表单参数
      infoType:null,
      form: {
        brandId:'',
        infoName:'',
        infoType:'',
        infoContent:'',
        isCollective:'',
      },
      currentIndex:0,
      // 表单校验
      rules: {
        infoName: [
          { required: true, message: "请输入名称", trigger: "blur" },
        ],
        brandId: [
          { required: true, message: "请选择类目", trigger: "blur" },
        ],
        infoContent: [
          { required: true, message: "请添加信息内容", trigger: "blur" },
        ],
      }
    };


  },
  methods: {
      titleClick(type){
        this.$parent.titleClick(type);
      },

      closeDialog(){
        this.$refs['form'].clearValidate()
        this.open=false
      },
      handleTabClick(item,index){
        this.currentIndex = index
        this.queryParams.brandId=item.brandId;
        this.infoType=item.brandType;
        this.getList()
      },
      handleClick(index,row,doType){
        let self=this;
        if(doType=='add'){//添加
          this.title='新增安全信息';
          this.$set(this,'form',{
            brandId:this.queryParams.brandId,
            infoType:this.infoType,
            infoName:'',
            infoContent:'',
          });
          this.open = true;
        }else if(doType=='edit'){//编辑
          this.title='编辑安全信息';
          this.$set(this,'form',{
            detailId:row.detailId,
            brandId:row.brandId,
            infoName:row.infoName,
            infoType:row.infoType,
            infoContent:row.infoContent,
            isCollective:row.isCollective,
            orderNum:row.orderNum,
          });
          this.open = true;
        }else if(doType=='deploy'){//信息牌配置
          self.pageType=2;
        }else if(doType=='delete'){//删除
          this.$confirm('确认要删除吗?', "警告", {
            confirmButtonText: "确定",
            cancelButtonText: "取消",
            type: "warning"
          }).then(() => {
            //  确定
            laboratoryBrandDetailDelete({detailId:row.detailId}).then(response => {
              this.msgSuccess(response.message);
              self.getList();
            });
          }).catch(function() {});
        }else if(doType=='back'){//返回
          self.pageType=1;
        }
      },
      categorySort(row){
        let obj={
          detailId:row.detailId,
          brandId:row.brandId,
          infoName:row.infoName,
          infoType:row.infoType,
          infoContent:row.infoContent,
          isCollective:row.isCollective,
          orderNum:row.orderNum,
        }
        laboratoryBrandDetailUpdate(obj).then( response => {
          this.msgSuccess(response.message);
          this.open = false;
          this.getList();
        });
      },
      categoryShow(row){
        //启用&停用
        let text = row.isCollective  ? "停用" : "启用";
        this.$confirm('是否确认' + text + '?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
        }).then(() => {
          let obj={
            detailId:row.detailId,
            brandId:row.brandId,
            infoName:row.infoName,
            infoType:row.infoType,
            infoContent:row.infoContent,
            isCollective:!row.isCollective,
            orderNum:row.orderNum,
          }
          laboratoryBrandDetailUpdate(obj).then( response => {
            this.msgSuccess(response.message);
            this.open = false;
            this.getList();
          });
        }).catch(() => {});
      },
      categoryClick(){
        let _this=this;
        this.form.infoContent='';
        this.categoryList.forEach(function(item) {
          if(item.brandId==_this.form.brandId){
            _this.$set(_this.form,'infoType',item.brandType);
          }
        })

      },
      /** 搜索按钮操作 */
      handleQuery() {
        this.queryParams.page = 1;
        this.getList();
      },
      /** 重置按钮操作 */
      resetQuery() {
        this.handleQuery();
      },
      /** 取消按钮 */
      cancel() {
        this.$refs['form'].clearValidate()
        this.open = false;
      },
      /** 提交按钮 */
      submitForm() {
        this.$refs["form"].validate(valid => {
          if (valid) {
            if (this.form.detailId) {
              laboratoryBrandDetailUpdate(this.form).then( response => {
                this.msgSuccess(response.message);
                this.open = false;
                this.getList();
              });
            } else {
              laboratoryBrandDetailAdd(this.form).then( response => {
                this.msgSuccess(response.message);
                this.open = false;
                this.getList();
              });
            }
          }
        });
      },
      //上传
      handleAvatarSuccess(res, file) {
        this.form.infoContent = res.data.url;
        this.$forceUpdate()
      },
      beforeAvatarUpload(file) {
        return new Promise((resolve, reject) => {
          if (file.type == 'image/png') {
            let reader = new FileReader()
            reader.readAsDataURL(file) // 必须用file.raw
            reader.onload = e => { // 让页面中的img标签的src指向读取的路径
              let img = e.target.result;
              const image = new Image()
              image.src=img
              image.onload = _=>{
                if(image.width <= 630 && image.height <= 78){
                  resolve()
                }else{
                  this.msgError('尺寸限制为最大630*78px，支持PNG格式')
                  reject();
                }
              }
            }
          }else{
            this.msgError('请上传PNG格式');
            reject();
          }
        })
      },
      //查询信息类目列表
      getCategoryList(){
        let obj={
          page: 1,
          pageSize:100,
          isShow:1,
        }
        laboratoryInfoBrandList(obj).then( response => {
          this.$set(this,'tabsList',response.data.records);
          this.$set(this,'categoryList',response.data.records);
          this.$set(this.queryParams,'brandId',response.data.records[0]?response.data.records[0].brandId+'':'');
          this.$set(this,'infoType',response.data.records[0]?response.data.records[0].brandType+'':'');
          this.getList()

        });
      },
      getList(){
        let _this=this;
        laboratoryBrandDetailList(_this.queryParams).then( response => {
          this.$set(this,'tableData',response.data.records);
          this.$set(this,'total',response.data.total);
        });
      },
  },
  mounted() {
    this.getCategoryList()

  }
};
</script>

<style scoped lang="scss">
  .safetyInfoConfig {
    overflow: hidden;
    flex:1;
    display: flex!important;
    flex-direction: column;
    .title-box{
      display: flex;
      border-bottom:1px solid #E0E0E0;
      margin-bottom:20px;
      div{
        height:80px;
        margin-right:20px;
        cursor: pointer;
        p:nth-child(1){
          font-size:18px;
          text-align: center;
          padding:0 20px;
          margin-top:26px;
        }
        p:nth-child(2){
          width:40px;
          height:4px;
          border-radius:40px;
          margin:12px auto;
        }
        .top-p-color{
          color: #0045AF;
        }
        .bottom-p-color{
          background: #0045AF;
        }
      }
      .buttonTitleColorA{
        color:#0045AF;
      }
      .buttonTitleColorB{
        color:#999999;
      }
    }
    .config_main{
        overflow: hidden;
        flex:1;
        display: flex;
        overflow: hidden;
       .config_main_l{
         flex: 1;
         padding-left: 42px;
         padding-top: 20px;
         .config_main_l_title{
           font-size: 16px;
           font-weight: 400;
           color: #0183FA;
           >img{
             width: 16px;
             height: 13px;
             margin-right: 12px;
           }
         }
         .config_main_l_li{
           font-size: 14px;
           font-family: Microsoft YaHei-Regular, Microsoft YaHei;
           font-weight: 400;
           color: #333333;
           line-height: 68px;
           cursor: pointer;
         }
         .active{
           color: #0183FA;
         }
       }
       .config_main_border{
         border-right: 1px dashed #A2A2A2;
         margin: 20px 35px 36px 0;
       }
      /*表格*/
      .approval_handle-page{
        display: flex!important;
        flex-direction: column;
        width: 1264px;
        padding:0px 20px 20px!important;
        .button-box{
          width:200px;
          display: flex;
        }
      }
    }

    .table-box{
      ::v-deep .el-input--medium .el-input__inner {
        height: 26px;
        line-height: 26px;
        width: 55px;
        text-align: center;
        padding: 0 10px;
      }
    }

  }

</style>
